==> libgrinvin-core-java_1.0.4.orig.tar.gz: grinvin-core-1.0.4/org/grinvin/gred/undoable/InternationalizedUndoableChange.java <==
/* InternationalizedUndoableChange.java
 * =========================================================================
 * This file is part of the GrInvIn project - http://www.grinvin.org
 * 
 * Copyright (C) 2005-2007 Universiteit Gent
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 * 
 * A copy of the GNU General Public License can be found in the file
 * LICENSE.txt provided with the source distribution of this program (see
 * the META-INF directory in the source jar). This license can also be
 * found on the GNU website at http://www.gnu.org/licenses/gpl.html.
 * 
 * If you did not receive a copy of the GNU General Public License along
 * with this program, contact the lead developer, or write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301, USA.
 */

package org.grinvin.gred.undoable;

import be.ugent.caagt.swirl.undoredo.UndoableChange;

import java.util.ResourceBundle;

/**
 * Common superclass of all implementations of {@link UndoableChange} with
 * internationalized captions. 
 * Provides storage for captions and an internationalized constructor.<p>
 * The methods {@link #undo} and {@link #redo} have a trivial implementation. 
 * This allows objects of this type to be used as dummy leaders of an 
 * undo/redo group.
 */
public class InternationalizedUndoableChange implements UndoableChange {
    
    //
    private String undoCaption;
    
    //
    private String redoCaption;
    
    //
    private ResourceBundle rbundle;
    
    /**
     * Construct an undoable change of this type with captions taken
     * from the resource bundle. The corresponding resource keys are constructed
     * from the given prefix by adding <tt>.undo</tt> and <tt>.redo</tt> 
     * respectively.
     */
    public InternationalizedUndoableChange (String keyPrefix) {
        rbundle = ResourceBundle.getBundle("org.grinvin.gred.undoable.resources");
        this.undoCaption = rbundle.getString(keyPrefix+".undo");
        this.redoCaption = rbundle.getString(keyPrefix+".redo");
    }
    
    // implements UndoableCommand
    public String getUndoCaption() {
        return this.undoCaption;
    }

    // implements UndoableCommand
    public String getRedoCaption() {
        return this.redoCaption;
    }

    /**
     * Does nothing.
     */
    public void undo() {
        // do nothing
    }

    /**
     * Does nothing.
     */
    public void redo() {
        // do nothing
    }
    
}

==> libgrinvin-core-java_1.2.orig.tar.gz: grinvin-core-1.2/org/grinvin/gred/undoable/InternationalizedUndoableChange.java <==
/* InternationalizedUndoableChange.java
 * =========================================================================
 * This file is part of the GrInvIn project - http://www.grinvin.org
 * 
 * Copyright (C) 2005-2008 Universiteit Gent
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 * 
 * A copy of the GNU General Public License can be found in the file
 * LICENSE.txt provided with the source distribution of this program (see
 * the META-INF directory in the source jar). This license can also be
 * found on the GNU website at http://www.gnu.org/licenses/gpl.html.
 * 
 * If you did not receive a copy of the GNU General Public License along
 * with this program, contact the lead developer, or write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301, USA.
 */

package org.grinvin.gred.undoable;

import be.ugent.caagt.swirl.undoredo.UndoableChange;

import java.util.ResourceBundle;

/**
 * Common superclass of all implementations of {@link UndoableChange} with
 * internationalized captions. 
 * Provides storage for captions and an internationalized constructor.<p>
 * The methods {@link #undo} and {@link #redo} have a trivial implementation. 
 * This allows objects of this type to be used as dummy leaders of an 
 * undo/redo group.
 */
public class InternationalizedUndoableChange implements UndoableChange {
    
    //
    private String undoCaption;
    
    //
    private String redoCaption;
    
    //
    private ResourceBundle rbundle;
    
    /**
     * Construct an undoable change of this type with captions taken
     * from the resource bundle. The corresponding resource keys are constructed
     * from the given prefix by adding <tt>.undo</tt> and <tt>.redo</tt> 
     * respectively.
     */
    public InternationalizedUndoableChange (String keyPrefix) {
        rbundle = ResourceBundle.getBundle("org.grinvin.gred.undoable.resources");
        this.undoCaption = rbundle.getString(keyPrefix+".undo");
        this.redoCaption = rbundle.getString(keyPrefix+".redo");
    }
    
    // implements UndoableChange
    public String getUndoCaption() {
        return this.undoCaption;
    }

    // implements UndoableChange
    public String getRedoCaption() {
        return this.redoCaption;
    }

    /**
     * Does nothing.
     */
    public void undo() {
        // do nothing
    }

    /**
     * Does nothing.
     */
    public void redo() {
        // do nothing
    }
    
}
